@@ -57,7 +57,7 @@
  *
  * Please see the file COPYING in the source's root directory.
  *
- * \author Ryan C. Gordon (icculus@clutteredmind.org)
+ * \author Ryan C. Gordon (icculus@icculus.org)
  * \author many others, please see CREDITS in the source's root directory.
  */
 
@@ -79,13 +79,15 @@ extern "C" {
 
 #ifdef SDL_SOUND_DLL_EXPORTS
 #  define SNDDECLSPEC __declspec(dllexport)
+#elif (__GNUC__ >= 3)
+#  define SNDDECLSPEC __attribute__((visibility("default")))
 #else
 #  define SNDDECLSPEC
 #endif
 
 #define SOUND_VER_MAJOR 1
 #define SOUND_VER_MINOR 0
-#define SOUND_VER_PATCH 1
+#define SOUND_VER_PATCH 3
 #endif
 
 
